aboutsummaryrefslogtreecommitdiff
path: root/platform/template/platform.c
diff options
context:
space:
mode:
Diffstat (limited to 'platform/template/platform.c')
-rw-r--r--platform/template/platform.c15
1 files changed, 3 insertions, 12 deletions
diff --git a/platform/template/platform.c b/platform/template/platform.c
index ef32941..84fbf56 100644
--- a/platform/template/platform.c
+++ b/platform/template/platform.c
@@ -162,17 +162,9 @@ static void platform_timer_event_stop(void)
}
/*
* Reboot the platform.
*/
-static int platform_system_reboot(u32 type)
-{
- return 0;
-}
-
-/*
- * Shutdown or poweroff the platform.
- */
-static int platform_system_shutdown(u32 type)
+static int platform_system_reset(u32 type)
{
return 0;
}
@@ -194,8 +186,7 @@ const struct sbi_platform_operations platform_ops = {
.timer_event_stop = platform_timer_event_stop,
.timer_event_start = platform_timer_event_start,
.timer_init = platform_timer_init,
- .system_reboot = platform_system_reboot,
- .system_shutdown = platform_system_shutdown
+ .system_reset = platform_system_reset
};
const struct sbi_platform platform = {
.opensbi_version = OPENSBI_VERSION,
@@ -162,17 +162,9 @@ static void platform_timer_event_stop(void)
}
/*
- * Reboot the platform.
+ * Reset the platform.
*/